@@ -7,10 +7,10 @@
 --  Author          : Sune Falck 
 --  Created On      : 6-Apr-2001
 --  Last Modified By: $Author: merdmann $
---  Last Modified On: $Date: 2004/03/06 20:01:09 $
+--  Last Modified On: $Date: 2006/12/12 19:02:11 $
 --  Status          : $State: Exp $
 --
---  Copyright (C) 2000-2001
+--  Copyright (C) 2000-2006
 --
 --  GNADE is copyrighted by the persons and institutions enumerated in the   --
 --  AUTHORS file. This file is located in the root directory of the          --
@@ -126,7 +126,7 @@ insert into employees values
 insert into employees values 
 (  3, 'Tully',		'Noel',		1001,	DATE'1959-01-23',	 2, 'Supervisor',    'T', 200.00 );
 insert into employees values 
-(  4, 'Pfeifer',	'Jrgen',	1001,	DATE'2001-01-01',	 2, 'Designer',	     'T', 200.00 );
+(  4, 'Pfeifer',	'Juergen',	1001,	DATE'2001-01-01',	 2, 'Designer',	     'T', 200.00 );
 insert into employees values 
 (  5, 'Smith',		'John',		1000,	DATE'1980-06-11',	 3, 'Coding Monkey', 'T', 250.00 );
 insert into employees values 
